@@ -1,7 +1,7 @@
 import pygal
-from pygal.style import DefaultStyle
-from .data import *
-from .math import sind, cosd
+from pygal.style import DefaultStyle, LightColorizedStyle, DarkStyle
+from xyw_utils.data import *
+from xyw_utils.math import sind, cosd
 
 
 def driving_resistance(gvw, vehicle_type='coach'):
